Jacek Caban : win32u: Store DPI awareness in ntuser_thread_info.

Alexandre Julliard julliard at winehq.org
Mon Aug 8 15:17:51 CDT 2022


Module: wine
Branch: master
Commit: f390b5b884a66f4c34340ebbe7ae731d52dd66ef
URL:    https://gitlab.winehq.org/wine/wine/-/commit/f390b5b884a66f4c34340ebbe7ae731d52dd66ef

Author: Jacek Caban <jacek at codeweavers.com>
Date:   Fri Jul 29 21:09:53 2022 +0200

win32u: Store DPI awareness in ntuser_thread_info.

---

 dlls/user32/sysparams.c      |  4 ++--
 dlls/win32u/ntuser_private.h |  1 -
 dlls/win32u/sysparams.c      |  4 ++--
 include/ntuser.h             | 17 +++++++++--------
 4 files changed, 13 insertions(+), 13 deletions(-)

diff --git a/dlls/user32/sysparams.c b/dlls/user32/sysparams.c
index 26259ab76e9..36b166c627c 100644
--- a/dlls/user32/sysparams.c
+++ b/dlls/user32/sysparams.c
@@ -888,7 +888,7 @@ UINT WINAPI GetDpiForSystem(void)
  */
 DPI_AWARENESS_CONTEXT WINAPI GetThreadDpiAwarenessContext(void)
 {
-    struct user_thread_info *info = get_user_thread_info();
+    struct ntuser_thread_info *info = NtUserGetThreadInfo();
 
     if (info->dpi_awareness) return ULongToHandle( info->dpi_awareness );
     return UlongToHandle( (NtUserGetProcessDpiAwarenessContext( GetCurrentProcess() ) & 3 ) | 0x10 );
@@ -899,7 +899,7 @@ DPI_AWARENESS_CONTEXT WINAPI GetThreadDpiAwarenessContext(void)
  */
 DPI_AWARENESS_CONTEXT WINAPI SetThreadDpiAwarenessContext( DPI_AWARENESS_CONTEXT context )
 {
-    struct user_thread_info *info = get_user_thread_info();
+    struct ntuser_thread_info *info = NtUserGetThreadInfo();
     DPI_AWARENESS prev, val = GetAwarenessFromDpiAwarenessContext( context );
 
     if (val == DPI_AWARENESS_INVALID)
diff --git a/dlls/win32u/ntuser_private.h b/dlls/win32u/ntuser_private.h
index e068ff849f3..b048d194a4e 100644
--- a/dlls/win32u/ntuser_private.h
+++ b/dlls/win32u/ntuser_private.h
@@ -129,7 +129,6 @@ struct user_thread_info
     WORD                          hook_unicode;           /* Is current hook unicode? */
     HHOOK                         hook;                   /* Current hook */
     UINT                          active_hooks;           /* Bitmap of active hooks */
-    DPI_AWARENESS                 dpi_awareness;          /* DPI awareness */
     INPUT_MESSAGE_SOURCE          msg_source;             /* Message source for current message */
     struct received_message_info *receive_info;           /* Message being currently received */
     struct wm_char_mapping_data  *wmchar_data;            /* Data for WM_CHAR mappings */
diff --git a/dlls/win32u/sysparams.c b/dlls/win32u/sysparams.c
index 5300d09eefe..ef2462e6540 100644
--- a/dlls/win32u/sysparams.c
+++ b/dlls/win32u/sysparams.c
@@ -1608,7 +1608,7 @@ UINT get_win_monitor_dpi( HWND hwnd )
  */
 DPI_AWARENESS get_thread_dpi_awareness(void)
 {
-    struct user_thread_info *info = get_user_thread_info();
+    struct ntuser_thread_info *info = NtUserGetThreadInfo();
     ULONG_PTR context = info->dpi_awareness;
 
     if (!context) context = NtUserGetProcessDpiAwarenessContext( NULL );
@@ -1677,7 +1677,7 @@ static DPI_AWARENESS get_awareness_from_dpi_awareness_context( DPI_AWARENESS_CON
  */
 DPI_AWARENESS_CONTEXT WINAPI SetThreadDpiAwarenessContext( DPI_AWARENESS_CONTEXT context )
 {
-    struct user_thread_info *info = get_user_thread_info();
+    struct ntuser_thread_info *info = NtUserGetThreadInfo();
     DPI_AWARENESS prev, val = get_awareness_from_dpi_awareness_context( context );
 
     if (val == DPI_AWARENESS_INVALID)
diff --git a/include/ntuser.h b/include/ntuser.h
index 6d0ae96ec6f..b36b630ce7f 100644
--- a/include/ntuser.h
+++ b/include/ntuser.h
@@ -61,14 +61,15 @@ enum
 /* TEB thread info, not compatible with Windows */
 struct ntuser_thread_info
 {
-    void      *driver_data;       /* driver-specific data */
-    DWORD      message_time;      /* value for GetMessageTime */
-    DWORD      message_pos;       /* value for GetMessagePos */
-    ULONG_PTR  message_extra;     /* value for GetMessageExtraInfo */
-    HWND       top_window;        /* desktop window */
-    HWND       msg_window;        /* HWND_MESSAGE parent window */
-    HIMC       default_imc;       /* default input context */
-    void      *client_imm;        /* client IMM thread info */
+    void          *driver_data;       /* driver-specific data */
+    DWORD          message_time;      /* value for GetMessageTime */
+    DWORD          message_pos;       /* value for GetMessagePos */
+    ULONG_PTR      message_extra;     /* value for GetMessageExtraInfo */
+    HWND           top_window;        /* desktop window */
+    HWND           msg_window;        /* HWND_MESSAGE parent window */
+    DPI_AWARENESS  dpi_awareness;     /* DPI awareness */
+    HIMC           default_imc;       /* default input context */
+    void          *client_imm;        /* client IMM thread info */
 };
 
 static inline struct ntuser_thread_info *NtUserGetThreadInfo(void)




More information about the wine-cvs mailing list